#
# spec file for package perl-Business-ISBN-Data
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Business-ISBN-Data
Name:           perl-Business-ISBN-Data
Version:        20250605.1.0
Release:        1.1
# 20250605.001 -> normalize -> 20250605.1.0
%define cpan_version 20250605.001
License:        Artistic-2.0
Summary:        Data pack for Business::ISBN
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/B/BR/BRIANDFOY/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.64
BuildRequires:  perl(Test::More) >= 1
BuildRequires:  perl(version) >= 0.86
Provides:       perl(Business::ISBN::Data) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
You don't need to load this module yourself in most cases. Business::ISBN
will load it when it loads. You must use Business::ISBN 3.005 or later
because the data structure changed slightly to fix a bug with ISBN13
prefixes.

These data are generated from the _RangeMessage.xml_ file provided by the
ISBN Agency. The distributed version matches the date in the version for
this module. You can retrieve this yourself at
https://www.isbn-international.org/range_file_generation. This file is
included as part of the distribution and should be installed at
_~lib/Business/ISBN/Data/RangeMessage.xml_.

If you want to use a different _RangeMessage.xml_ file, you can set the
'ISBN_RANGE_MESSAGE' environment variable to the alternate location before
you load 'Business::ISBN'. This way, you can use the latest (or even
earlier) data without having to install something new or wait for an update
to this module.

If the default _RangeMessage.xml_ or your alternate one is not available,
the module falls back to data included in _Data.pm_. However, that data are
likely to be older. If it does not find that file, it looks for
_RangeMessage.xml_ in the current directory.

The data are in '%Business::ISBN::country_data' (although the "country"
part is historical). If you want to see where the data are from, check
'$Business::ISBN::country_data{_source}'.

%prep
%autosetup -n %{cpan_name}-%{cpan_version} -p1

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes examples SECURITY.md
%license LICENSE

%changelog
* Fri Jun  6 2025 Tina Müller <timueller+perl@suse.de>
- updated to 20250605.1.0 (20250605.001)
  see /usr/share/doc/packages/perl-Business-ISBN-Data/Changes
  20250605.001 2025-06-05T17:09:04Z
  * data update for 2025-06-05
* Thu May 22 2025 Tina Müller <timueller+perl@suse.de>
- updated to 20250521.1.0 (20250521.001)
  see /usr/share/doc/packages/perl-Business-ISBN-Data/Changes
  20250521.001 2025-05-21T11:37:03Z
  * data update for 2025-05-21
  20250516.001 2025-05-16T04:40:11Z
  * data update for 2025-05-16
  20250502.001 2025-05-02T14:14:49Z
  * data update for 2025-05-02
  20250426.001 2025-04-28T13:04:20Z
  * data update for 2025-04-26
  20250418.001 2025-04-18T08:10:56Z
  * data update for 2025-04-18
  20250416.001 2025-04-16T05:46:53Z
  * data update 2025-04-16
  20250411.001 2025-04-11T17:39:39Z
  * Data update for 205-04-11
  20250322.001 2025-03-22T05:59:36Z
  * data update for 2025-03-21
  20250315.001 2025-03-15T04:51:26Z
  * data update for 2025-03-14
  20250309.001 2025-03-10T02:14:14Z
  * data update for 2025-03-09
  20250226.001 2025-02-26T13:54:49Z
  * data update for 2025-02-26
  20250220.001 2025-02-20T09:13:32Z
  * data update for 2025-02-19
* Thu Feb  6 2025 Tina Müller <timueller+perl@suse.de>
- updated to 20250205.1.0 (20250205.001)
  see /usr/share/doc/packages/perl-Business-ISBN-Data/Changes
  20250205.001 2025-02-05T16:56:48Z
  * data update for 2025-02-05
* Wed Jan 22 2025 Tina Müller <timueller+perl@suse.de>
- updated to 20250118.1.0 (20250118.001)
  see /usr/share/doc/packages/perl-Business-ISBN-Data/Changes
  20250118.001 2025-01-18T08:16:08Z
  * data update for 2025-01-18
  20250116.001 2025-01-16T03:44:41Z
  * data update for 2025-01-16
  20250115.001 2025-01-15T07:28:33Z
  * data update for 2025-01-15
* Fri Jan 10 2025 Tina Müller <timueller+perl@suse.de>
- updated to 20250109.1.0 (20250109.001)
  see /usr/share/doc/packages/perl-Business-ISBN-Data/Changes
  20250109.001 2025-01-09T07:47:59Z
  * data update for 2025-01-09
* Tue Dec 24 2024 Tina Müller <timueller+perl@suse.de>
- updated to 20241224.1.0 (20241224.001)
  see /usr/share/doc/packages/perl-Business-ISBN-Data/Changes
  20241224.001 2024-12-24T04:16:05Z
  * data update for 2024-12-24
  20241220.001 2024-12-20T12:09:49Z
  * data update for 2024-12-20
  20241206.001 2024-12-07T16:13:59Z
  * Data update for 2024-12-06
  20241205.001 2024-12-05T04:10:05Z
  * 2024-12-04 data update
  20241130.001 2024-11-30T11:38:06Z
  * data update for 2024-11-30
  20241123.001 2024-11-23T04:35:44Z
  * data update for 2024-11-22
  20241112.001 2024-11-12T14:28:30Z
  * data update for 2024-11-12
  20241107.001 2024-11-07T04:42:32Z
  * data update for 2024-11-06
  20241105.001 2024-11-06T01:48:47Z
  * data update for 2024-11-05
  20241025.001 2024-10-25T13:29:03Z
  * data update for 2024-10-25
  20241019.001 2024-10-19T15:49:53Z
  * data update for 2024-10-19
  20241017.001 2024-10-17T17:17:24Z
  * data update for 2024-10-17
  20241014.001 2024-10-14T20:18:10Z
  * data update for 2024-10-14
  20240930.001 2024-09-30T06:16:15Z
  * data update for 2024-09-30
  20240918.001 2024-09-18T16:07:47Z
  * data update for 2024-09-18
  20240914.001 2024-09-14T21:30:59Z
  * data update for 2024-09-14
  20240906.001 2024-09-06T13:48:17Z
  * data update for 2024-09-06
* Wed Aug 21 2024 Tina Müller <timueller+perl@suse.de>
- updated to 20240821.1.0 (20240821.001)
  see /usr/share/doc/packages/perl-Business-ISBN-Data/Changes
  20240821.001 2024-08-21T04:02:47Z
  * data update for 2024-08-21
  20240820.001 2024-08-20T06:42:42Z
  * data update for 2024-08-20
  20240817.001 2024-08-17T05:05:37Z
  * data update for 2024-08-17
  20240815.001 2024-08-15T14:49:49Z
  * data update for 2024-08-15
  20240807.001 2024-08-07T11:20:33Z
  * data update for 2024-08-07
  20240803.001 2024-08-03T04:03:06Z
  * data update for 2024-08-03
* Fri Jul 26 2024 Tina Müller <timueller+perl@suse.de>
- updated to 20240725.1.0 (20240725.001)
  see /usr/share/doc/packages/perl-Business-ISBN-Data/Changes
  20240725.001 2024-07-25T06:11:46Z
  * data update for 2024-07-25
* Fri Jul 19 2024 Tina Müller <timueller+perl@suse.de>
- updated to 20240718.1.0 (20240718.001)
  see /usr/share/doc/packages/perl-Business-ISBN-Data/Changes
  20240718.001 2024-07-18T17:14:53Z
  * data update for 2024-07-18
  20240716.001 2024-07-16T15:45:27Z
  * Data update for 2024-07-16
  * this distribution now uses GitHub Attestions. See README.pod.
* Thu Jul 11 2024 Tina Müller <timueller+perl@suse.de>
- updated to 20240710.1.0 (20240710.001)
  see /usr/share/doc/packages/perl-Business-ISBN-Data/Changes
  20240710.001 2024-07-10T10:46:31Z
  * data update for 2024-07-10
  20240709.001 2024-07-09T13:20:22Z
  * data update for 2024-07-09
* Sun Jun 23 2024 Tina Müller <tina.mueller@suse.com>
- updated to 20240614.1.0 (20240614.001)
  see /usr/share/doc/packages/perl-Business-ISBN-Data/Changes
  20240614.001 2024-06-14T20:50:14Z
  * Data update for 2024-06-14
  20240601.001 2024-06-01T13:28:51Z
  * data update for 2024-06-01
  20240523.001 2024-05-23T14:35:01Z
  * data update for 2024-05-23
* Fri May 10 2024 Tina Müller <timueller+perl@suse.de>
- updated to 20240509.001
  see /usr/share/doc/packages/perl-Business-ISBN-Data/Changes
  20240509.001 2024-05-09T18:55:16Z
  * data update for 2024-05-09
  20240427.001 2024-04-27T10:36:58Z
  * data update for 2024-04-27
  20240426.001 2024-04-26T11:41:31Z
  * data update for 2024-04-26
  20240420.001 2024-04-20T11:39:16Z
  * data update for 2024-04-20
  20240413.001 2024-04-13T19:53:52Z
  * data update for 2024-04-13
  20240323.001 2024-03-23T08:30:28Z
  * Data update for 2023-03-23
  20240321.001 2024-03-21T07:16:25Z
  * Data update for 2024-03-21
  20240313.001 2024-03-13T08:28:48Z
  * Data update for 2024-03-13
  20240308.001 2024-03-08T08:32:18Z
  * Data update for 2024-03-08
  20240302.001 2024-03-02T23:33:19Z
  * Data update for 2024-03-02
  20240229.001 2024-02-29T21:17:00Z
  * Data update for 2024-02-29 (Leap day!)
  20240209.001 2024-02-09T21:13:28Z
  * data update for 2024-02-09
  20240206.001 2024-02-06T04:11:18Z
  * data update for 2024-02-06
  20240126.001 2024-01-26T04:20:55Z
  * Data update for 2024-01-25
  20240123.001 2024-01-23T14:52:26Z
  * Data update for 2024-01-23
  20240116.001 2024-01-16T14:01:15Z
  * Data upate for 2024-01-16
  20240111.001 2024-01-11T19:06:03Z
  * Data update for 2014-01-11
* Sat Dec 23 2023 Tina Müller <timueller+perl@suse.de>
- updated to 20231220.001
  see /usr/share/doc/packages/perl-Business-ISBN-Data/Changes
  20231220.001 2023-12-21T08:59:21Z
  * data update for 2023-12-20
  20231215.001 2023-12-15T05:56:18Z
  * data update for 2023-12-15
  20231130.001 2023-11-30T15:44:22Z
  * data update for 2023-11-30
  20231125.001 2023-11-25T07:20:29Z
  * Data update for 2023-11-25
  20231118.001 2023-11-18T09:36:00Z
  * data update for 2023-11-18
  20231114.001 2023-11-14T07:06:33Z
  * data update for 2023-11-14
  20231110.001 2023-11-10T07:58:12Z
  * data update for 2023-11-10
  20231102.001 2023-11-02T05:03:05Z
  * Data update for 2023-11-02
  20231031.001 2023-10-31T14:31:39Z
  * Data update for 2023-10-31
* Sat Oct 21 2023 Tina Müller <timueller+perl@suse.de>
- updated to 20231020.001
  see /usr/share/doc/packages/perl-Business-ISBN-Data/Changes
  20231020.001 2023-10-20T08:12:42Z
  * Data update for 2023-10-20
* Sat Oct 14 2023 Tina Müller <timueller+perl@suse.de>
- updated to 20231013.001
  see /usr/share/doc/packages/perl-Business-ISBN-Data/Changes
  20231013.001 2023-10-13T12:09:42Z
  * data update for 2023-10-13
  20231010.001 2023-10-10T13:02:37Z
  * data update for 2023-10-10
  20231006.001 2023-10-08T02:04:15Z
  * data update for 2023-10-06
* Wed Sep 27 2023 Tina Müller <timueller+perl@suse.de>
- updated to 20230926.001
  see /usr/share/doc/packages/perl-Business-ISBN-Data/Changes
  20230926.001 2023-09-26T09:01:09Z
  * Data update for 2023-09-26
  20230923.001 2023-09-23T19:43:19Z
  * Data update for 20230923
  20230922.001 2023-09-23T00:18:18Z
  * Data update for 20230922
* Fri Sep  8 2023 Tina Müller <timueller+perl@suse.de>
- updated to 20230907.001
  see /usr/share/doc/packages/perl-Business-ISBN-Data/Changes
  20230907.001 2023-09-07T09:34:02Z
  * data update for 2023-09-07
* Tue Sep  5 2023 Tina Müller <timueller+perl@suse.de>
- updated to 20230904.001
  see /usr/share/doc/packages/perl-Business-ISBN-Data/Changes
  20230904.001 2023-09-05T01:54:08Z
  * Data update for 2023-09-04
  20230830.001 2023-08-30T11:43:37Z
  Data update for 2023-08-30
* Wed Aug 23 2023 Tina Müller <timueller+perl@suse.de>
- updated to 20230822.001
  see /usr/share/doc/packages/perl-Business-ISBN-Data/Changes
  20230822.001 2023-08-22T05:23:14Z
  * Data update for 2023-08-22
  20230811.001 2023-08-11T09:23:24Z
  * Data update for 2023-08-11
* Sun Jul 30 2023 Tina Müller <timueller+perl@suse.de>
- updated to 20230729.001
  see /usr/share/doc/packages/perl-Business-ISBN-Data/Changes
  20230729.001 2023-07-29T20:53:52Z
  * Data update for 2023-07-29
* Thu Jul 20 2023 Tina Müller <timueller+perl@suse.de>
- updated to 20230719.001
  see /usr/share/doc/packages/perl-Business-ISBN-Data/Changes
  20230719.001 2023-07-19T19:30:03Z
  * Data update for 2023-07-19
  20230718.001 2023-07-18T19:22:42Z
  * Data update for 20230718.001
  20230714.001 2023-07-14T07:35:39Z
  * Data update for 20230707
  20230707.001 2023-07-07T03:52:07Z
  * Data update for 20230707
  20230626.001 2023-06-26T15:49:00Z
  * Data update for 20230626
* Mon May 29 2023 Tina Müller <timueller+perl@suse.de>
- updated to 20230528.001
  see /usr/share/doc/packages/perl-Business-ISBN-Data/Changes
  20230528.001 2023-05-28T21:01:11Z
  * Update for 2023-05-28
  20230516.001 2023-05-16T15:09:45Z
  * Data update for May 16, 2023
  20230426.002 2023-05-04T04:20:45Z
  * fix a problem with the MANIFEST (#30). No data updates.
* Thu Apr 27 2023 Tina Müller <timueller+perl@suse.de>
- updated to 20230426.001
  see /usr/share/doc/packages/perl-Business-ISBN-Data/Changes
  20230426.001 2023-04-26T20:39:21Z
  Data update for 20230426
* Tue Apr 11 2023 Tina Müller <timueller+perl@suse.de>
- updated to 20230410.001
  see /usr/share/doc/packages/perl-Business-ISBN-Data/Changes
  20230410.001 2023-04-10T06:25:50Z
  * Data update for 2023-04-10
  20230331.001 2023-04-03T05:04:52Z
  * Data update for 2023-03-30
* Thu Mar 23 2023 Tina Müller <timueller+perl@suse.de>
- updated to 20230322.001
  see /usr/share/doc/packages/perl-Business-ISBN-Data/Changes
  20230322.001 2023-03-22T18:22:12Z
  * ISBN data for 20230322.001
  20230316.001 2023-03-16T14:14:06Z
  * Update data to March 2023
* Wed Feb 17 2021 Tina Müller <timueller+perl@suse.de>
- updated to 20210112.006
  see /usr/share/doc/packages/perl-Business-ISBN-Data/Changes
  20210112.006 2021-02-16T04:08:08Z
  * Fix testing bug. This module needs Business::ISBN 3.005 to match
  the data structures. Prior to that, Business::ISBN had a bug with
  ISBN13.
  20210112.005_03 2021-02-15T17:43:08Z
  * I think the CPAN Tester failures are using older versions of
  Business::ISBN (older than 3.005 all seem to fail). I assumed they
  started fresh, but I guess not. Require a recent version in the
  default_data test.
  20210112.005_02 2021-02-14T05:07:05Z
  * Try harder to see what's going on in CPAN Testers
  20210112.005_01 2021-02-13T12:40:28Z
  * Try harder to figure out these test failures
* Sun Feb 14 2021 Tina Müller <timueller+perl@suse.de>
- updated to 20210112.005
  see /usr/share/doc/packages/perl-Business-ISBN-Data/Changes
* Thu Feb 11 2021 Tina Müller <timueller+perl@suse.de>
- updated to 20210112.004
  see /usr/share/doc/packages/perl-Business-ISBN-Data/Changes
  20210112.004 2021-02-10T04:29:32Z
  * Test the default data.
  * Add a note about packaging RangeMessage.xml (adapted from gwyn17)
* Wed Feb 10 2021 Tina Müller <timueller+perl@suse.de>
- updated to 20210112.003
  see /usr/share/doc/packages/perl-Business-ISBN-Data/Changes
  20210112.003 2021-02-09T22:42:53Z
  * The default data had a problem because I used the same hash key
  twice in the default data (Github #7). Found by gwyn17.
* Mon Feb  8 2021 Tina Müller <timueller+perl@suse.de>
- updated to 20210112.002
  see /usr/share/doc/packages/perl-Business-ISBN-Data/Changes
  20210112.002 2021-02-07T05:46:20Z
  * Don't try to load a data file if there are no data files
  (Github #6)
* Wed Jan 20 2021 Tina Müller <timueller+perl@suse.de>
- updated to 20210112.001
  see /usr/share/doc/packages/perl-Business-ISBN-Data/Changes
  20210112.001 2021-01-19T14:48:12Z
  * freshen distro, dump Travis CI, add Github Actions
  * Update to latest Business::ISBN::Data
* Thu Dec 12 2019 <timueller+perl@suse.de>
- updated to 20191107
  see /usr/share/doc/packages/perl-Business-ISBN-Data/Changes
  20191107 2019-12-11T20:04:42Z
  * Peter Williams fixed the 978/979 distinction (GitHub #5)
* Thu Dec 17 2015 coolo@suse.com
- updated to 20140910.003
  see /usr/share/doc/packages/perl-Business-ISBN-Data/Changes
  Revision history for Perl module
- Drop fix-provides.diff (included upstream)
* Thu Feb 19 2015 coolo@suse.com
- updated to 20140910.002
  * Look in the current directory for RangeMessage.xml if it's
    not in other locations. This can help with various Perl app
    packagers. (But, also try ISBN_RANGE_MESSAGE env var)
- add fix-provides.diff to avoid providing ::ISBN without data
* Sun Sep 21 2014 lars@linux-schulserver.de
- updated to 20140910.001:
  * Update to the latest data (2014-09-10)
- fix perl path in make_data.pl
* Tue Jun  4 2013 coolo@suse.com
- updated to 20120719.001
  * Support data from RangeMessage.xml. You can use the latest
    data from ISBN without updating this module.
    Specify the Test::More version so I cna use subtest.
    No code or feature changes
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Sat Sep  4 2010 chris@computersalat.de
- recreated by cpanspec 1.78
- noarch pkg
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Sat Jul 25 2009 chris@computersalat.de
- spec mods
  * removed ^----------
  * removed ^#---------
* Sun Jun 28 2009 chris@computersalat.de
- update to 20081208
  - 0.00 - Fri Dec  5 12:00:41 2008
  * Latest data update.
  - 20081020 - Mon Oct 20 17:44:15 2008
  * Updated publisher codes thanks to Yakov Shafranovich
  * Version number is now the update date of the module,
    in YYYYMMDD. This not the date of the ISBN Agency
    updates though.
- added perl-macros
  o autogen filelist with perl_gen_filelist
- spec mods
  o fixed deps
* Tue Feb 12 2008 lars@linux-schulserver.de
- Update to 1.17:
  [BUGFIX] RT #29078: Fix publihser ranges for Greece
* Mon Jul 23 2007 lrupp@suse.de
- initial package 1.14
